package com.doverfuelingsolutions.issp

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.text.InputType
import android.view.MenuItem
import androidx.appcompat.app.AppCompatActivity
import androidx.preference.EditTextPreference
import androidx.preference.Preference
import androidx.preference.PreferenceFragmentCompat
import com.doverfuelingsolutions.issp.utils.StringUtil
import com.doverfuelingsolutions.issp.utils.sp.SPKeys

class PreferenceActivity : AppCompatActivity() {

    companion object {

        fun start(context: Context) {
            Intent(context, PreferenceActivity::class.java).let { context.startActivity(it) }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.settings_activity)
        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        if (savedInstanceState == null) {
            supportFragmentManager
                .beginTransaction()
                .replace(R.id.settings, SettingsFragment())
                .commit()
        }
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        when (item.itemId) {
            android.R.id.home -> finish()
        }
        return super.onOptionsItemSelected(item)
    }

    class SettingsFragment : PreferenceFragmentCompat() {

        private val editTextPreferenceSummaryProvider = Preference.SummaryProvider<EditTextPreference> {
            if (it.text.isNullOrEmpty()) StringUtil.get(R.string.not_set) else it.text
        }

        override fun onCreatePreferences(savedInstanceState: Bundle?, rootKey: String?) {
            setPreferencesFromResource(R.xml.root_preferences, rootKey)

            val p1 = findPreference<EditTextPreference>(SPKeys.SERVER_PORT_BASE)
            val p2 = findPreference<EditTextPreference>(SPKeys.SERVER_PORT_TRX)
            val p3 = findPreference<EditTextPreference>(SPKeys.SERVER_PORT_CONFIG)
            val p4 = findPreference<EditTextPreference>(SPKeys.MIDDLE_PORT)
            val p5 = findPreference<EditTextPreference>(SPKeys.MIDDLE_WORKSTATION_ID)
            val p6 = findPreference<EditTextPreference>(SPKeys.FUEL_PORT)
            val p7 = findPreference<EditTextPreference>(SPKeys.MIDDLE_IP)
            val p8 = findPreference<EditTextPreference>(SPKeys.FUEL_IP)

            InputType.TYPE_CLASS_NUMBER.let { type ->
                p1?.setOnBindEditTextListener { it.inputType = type }
                p2?.setOnBindEditTextListener { it.inputType = type }
                p3?.setOnBindEditTextListener { it.inputType = type }
                p4?.setOnBindEditTextListener { it.inputType = type }
                p5?.setOnBindEditTextListener { it.inputType = type }
                p6?.setOnBindEditTextListener { it.inputType = type }
            }

            editTextPreferenceSummaryProvider.let {
                p1?.summaryProvider = it
                p2?.summaryProvider = it
                p3?.summaryProvider = it
                p4?.summaryProvider = it
                p5?.summaryProvider = it
                p6?.summaryProvider = it
                p7?.summaryProvider = it
                p8?.summaryProvider = it
            }
        }

    }
}